@@ -15,7 +15,7 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License 
+   You should have received a copy of the GNU General Public License
    along with this library; see the file COPYING. If not, write to the
    Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301, USA.
@@ -59,31 +59,31 @@ union float_long
  **********************************************/
 
 /* Trigonometric functions */
-float sinf(const float x) _MATH_REENTRANT;
-float cosf(const float x) _MATH_REENTRANT;
-float tanf(const float x) _MATH_REENTRANT;
-float cotf(const float x) _MATH_REENTRANT;
-float asinf(const float x) _MATH_REENTRANT;
-float acosf(const float x) _MATH_REENTRANT;
-float atanf(const float x) _MATH_REENTRANT;
-float atan2f(const float x, const float y);
+float sinf(float x) _MATH_REENTRANT;
+float cosf(float x) _MATH_REENTRANT;
+float tanf(float x) _MATH_REENTRANT;
+float cotf(float x) _MATH_REENTRANT;
+float asinf(float x) _MATH_REENTRANT;
+float acosf(float x) _MATH_REENTRANT;
+float atanf(float x) _MATH_REENTRANT;
+float atan2f(float x, float y);
 
 /* Hyperbolic functions */
-float sinhf(const float x) _MATH_REENTRANT;
-float coshf(const float x) _MATH_REENTRANT;
-float tanhf(const float x) _MATH_REENTRANT;
+float sinhf(float x) _MATH_REENTRANT;
+float coshf(float x) _MATH_REENTRANT;
+float tanhf(float x) _MATH_REENTRANT;
 
 /* Exponential, logarithmic and power functions */
-float expf(const float x);
-float logf(const float x) _MATH_REENTRANT;
-float log10f(const float x) _MATH_REENTRANT;
-float powf(const float x, const float y);
-float sqrtf(const float a) _MATH_REENTRANT;
+float expf(float x);
+float logf(float x) _MATH_REENTRANT;
+float log10f(float x) _MATH_REENTRANT;
+float powf(float x, float y);
+float sqrtf(float a) _MATH_REENTRANT;
 
 /* Nearest integer, absolute value, and remainder functions */
-float fabsf(const float x) _MATH_REENTRANT;
-float frexpf(const float x, int *pw2);
-float ldexpf(const float x, const int pw2);
+float fabsf(float x) _MATH_REENTRANT;
+float frexpf(float x, int *pw2);
+float ldexpf(float x, int pw2);
 float ceilf(float x) _MATH_REENTRANT;
 float floorf(float x) _MATH_REENTRANT;
 float modff(float x, float * y);
