@@ -1,7 +1,7 @@
 /*-------------------------------------------------------------------------
    asinf.c - Computes asin(x)
 
-   Copyright (C) 2001,2002, Jesus Calvino-Fraga, jesusc@ieee.org 
+   Copyright (C) 2001,2002, Jesus Calvino-Fraga, jesusc@ieee.org
 
    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -13,7 +13,7 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License 
+   You should have received a copy of the GNU General Public License
    along with this library; see the file COPYING. If not, write to the
    Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301, USA.
@@ -28,13 +28,12 @@
 
 #include <math.h>
 
-float asincosf(const float x, const int isacos);
+float asincosf(float x, int isacos);
 
-float asinf(const float x) _MATH_REENTRANT
+float asinf(float x) _MATH_REENTRANT
 {   
          if(x== 1.0) return  HALF_PI;
     else if(x==-1.0) return -HALF_PI;
     else if(x== 0.0) return 0.0;
     else return asincosf(x,0);
 }
-
