@@ -13,7 +13,7 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License 
+   You should have received a copy of the GNU General Public License
    along with this library; see the file COPYING. If not, write to the
    Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301, USA.
@@ -29,7 +29,7 @@
 #include <math.h>
 #include <errno.h>
 
-float ldexpf(const float x, const int pw2)
+float ldexpf(float x, int pw2)
 {
     union float_long fl;
     long e;
