@@ -480,7 +480,7 @@ cl_hc08::exec_inst(void)
         case 0xc: return(inst_clrh(code, false));
         case 0xe: return(inst_stop(code, false));
         case 0xf: return(inst_wait(code, false));
-        default: return(resHALT);
+        default: return(resINV_INST); // 0x82 and 0x8d not valid
       }
     case 0x9:
       switch (code & 0xf) {
@@ -489,7 +489,8 @@ cl_hc08::exec_inst(void)
         case 0x2:
         case 0x3: return(inst_condbranch(code, false));
         case 0x4:
-        case 0x5:
+        case 0x5: return(inst_transfer(code, false));
+        case 0x6: return(inst_sthx(code, false));
         case 0x7:
         case 0xf: return(inst_transfer(code, false));
         case 0x8:
@@ -498,8 +499,9 @@ cl_hc08::exec_inst(void)
         case 0xb: return(inst_setclearflags(code, false));
         case 0xc: return(inst_rsp(code, false));
         case 0xd: return(inst_nop(code, false));
-        case 0xe:
+        case 0xe: // start 0x9e prefix handling
           code = fetch();
+          tick(1);
           switch ((code >> 4) & 0xf) {
             case 0x6:
               switch (code & 0xf) {
@@ -516,22 +518,22 @@ cl_hc08::exec_inst(void)
                 case 0xc: return(inst_inc(code, true));
                 case 0xd: return(inst_tst(code, true));
                 case 0xf: return(inst_clr(code, true));
-                default: return(resHALT);
+                default: return(resINV_INST); // 0x9e62, 0x9e65, 0x9e6e not valid
               }
             case 0xa:
-              switch (code & 0x5) {
-                case 0xe: return(inst_ldhx(code,true));
-                default: return(resHALT);
+              switch (code) {
+                case 0xae: return(inst_ldhx(code,true));
+                default: return(resINV_INST);
               }
             case 0xb:
-              switch (code & 0x5) {
-                case 0xe: return(inst_ldhx(code,true));
-                default: return(resHALT);
+              switch (code) {
+                case 0xbe: return(inst_ldhx(code,true));
+                default: return(resINV_INST);
               }
             case 0xc:
-              switch (code & 0x5) {
-                case 0xe: return(inst_ldhx(code,true));
-                default: return(resHALT);
+              switch (code) {
+                case 0xce: return(inst_ldhx(code,true));
+                default: return(resINV_INST);
               }
             case 0xd:
             case 0xe:
@@ -548,8 +550,8 @@ cl_hc08::exec_inst(void)
                 case 0x9: return(inst_adc(code, true));
                 case 0xa: return(inst_ora(code, true));
                 case 0xb: return(inst_add(code, true));
-                case 0xc: return(resHALT);
-                case 0xd: putchar(regs.A); fflush(stdout); return(resGO);
+		case 0xc: return(resHALT); // not real instruction: regression test hack to exit simulation
+		case 0xd: putchar(regs.A); fflush(stdout); return(resGO); // not real instruction: regression test hack to output results
                 case 0xe: return(inst_ldx(code, true));
                 case 0xf: return(inst_stx(code, true));
                 default: return(resHALT);
@@ -560,7 +562,8 @@ cl_hc08::exec_inst(void)
                 case 0xe: return(inst_ldhx(code, true));
                 case 0xf: return(inst_sthx(code, true));
               }
-            default: return(resHALT);
+            default: return(resINV_INST);
+	    // end 0x9e prefix handling
           }
 
       }
@@ -589,7 +592,7 @@ cl_hc08::exec_inst(void)
         case 0xb: return(inst_add(code, false));
         case 0xc:
           if (code==0xac)
-            return(resHALT);
+            return(resINV_INST);
           else
             return(inst_jmp(code, false));
         case 0xd:
