@@ -1068,15 +1068,13 @@ cl_z80::inst_ret(t_mem code)
 int
 cl_z80::inst_call(t_mem code)
 {
-  int jnk;
-
   switch(code) {
     case 0xC4: // CALL NZ,nnnn
       if (!(regs.F & BIT_Z)) {
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xCC: // CALL Z,nnnn
@@ -1084,7 +1082,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xCD: // CALL nnnn
@@ -1096,7 +1094,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xDC: // CALL C,nnnn
@@ -1104,7 +1102,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xE4: // CALL PO,nnnn
@@ -1112,7 +1110,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xEC: // CALL PE,nnnn
@@ -1120,7 +1118,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xF4: // CALL P,nnnn
@@ -1128,7 +1126,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     case 0xFC: // CALL M,nnnn
@@ -1136,7 +1134,7 @@ cl_z80::inst_call(t_mem code)
         push2(PC+2);
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     default:
@@ -1280,14 +1278,12 @@ cl_z80::inst_pop(t_mem code)
 int
 cl_z80::inst_jp(t_mem code)
 {
-  int jnk;
-
   switch (code) {
     case 0xC2: // JP NZ,nnnn
       if (!(regs.F & BIT_Z)) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1299,7 +1295,7 @@ cl_z80::inst_jp(t_mem code)
       if (regs.F & BIT_Z) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1307,7 +1303,7 @@ cl_z80::inst_jp(t_mem code)
       if (!(regs.F & BIT_C)) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1315,7 +1311,7 @@ cl_z80::inst_jp(t_mem code)
       if (regs.F & BIT_C) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1323,7 +1319,7 @@ cl_z80::inst_jp(t_mem code)
       if (!(regs.F & BIT_P)) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1335,7 +1331,7 @@ cl_z80::inst_jp(t_mem code)
       if (regs.F & BIT_P) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1343,7 +1339,7 @@ cl_z80::inst_jp(t_mem code)
       if (!(regs.F & BIT_S)) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
 
@@ -1351,7 +1347,7 @@ cl_z80::inst_jp(t_mem code)
       if (regs.F & BIT_S) {
         PC = fetch2();
       } else {
-        jnk = fetch2();
+        fetch2();
       }
     break;
     default:
