@@ -43,6 +43,7 @@ struct _dumpFiles dumpFiles[] = {
   {DUMP_PACK, ".dumppack", NULL},
   {DUMP_RASSGN, ".dumprassgn", NULL},
   {DUMP_LRANGE, ".dumplrange", NULL},
+  {DUMP_LOSPRE, ".dumplospre", NULL},
   {0, NULL, NULL}
 };
 
@@ -313,6 +314,7 @@ iCode2eBBlock (iCode * ic)
 
   /* put the first one unconditionally */
   ebb->sch = ic;
+  ic->seq = 0;
 
   /* if this is a label then */
   if (ic->op == LABEL)
@@ -359,6 +361,7 @@ iCode2eBBlock (iCode * ic)
   /* loop thru till we find one with a label */
   for (loop = ic->next; loop; loop = loop->next)
     {
+      loop->seq = 0;
 
       /* if this is the last one */
       if (!loop->next)
