@@ -252,7 +252,7 @@ bitVectIntersect (bitVect * bvp1, bitVect * bvp2)
 /*                       if the vectors have any common bits set   */
 /*-----------------------------------------------------------------*/
 int 
-bitVectBitsInCommon (bitVect * bvp1, bitVect * bvp2)
+bitVectBitsInCommon (const bitVect * bvp1, const bitVect * bvp2)
 {
   int i;
   int nbits;
@@ -328,7 +328,7 @@ bitVectCplAnd (bitVect * bvp1, bitVect * bvp2)
 /* bitVectIsZero - bit vector has all bits turned off              */
 /*-----------------------------------------------------------------*/
 int 
-bitVectIsZero (bitVect * bvp)
+bitVectIsZero (const bitVect * bvp)
 {
   int i;
 
@@ -370,7 +370,7 @@ bitVectEqual (bitVect * bvp1, bitVect * bvp2)
 /* bitVectCopy - creates a bitvector from another bit Vector       */
 /*-----------------------------------------------------------------*/
 bitVect *
-bitVectCopy (bitVect * bvp)
+bitVectCopy (const bitVect * bvp)
 {
   bitVect *newBvp;
   int i;
@@ -389,7 +389,7 @@ bitVectCopy (bitVect * bvp)
 /* bitVectnBitsOn - returns the number of bits that are on         */
 /*-----------------------------------------------------------------*/
 int 
-bitVectnBitsOn (bitVect * bvp)
+bitVectnBitsOn (const bitVect * bvp)
 {
   int i, j;
   unsigned char byte;
@@ -450,7 +450,7 @@ bitVectnBitsOn (bitVect * bvp)
 /* bitVectFirstBit - returns the key for the first bit that is on  */
 /*-----------------------------------------------------------------*/
 int 
-bitVectFirstBit (bitVect * bvp)
+bitVectFirstBit (const bitVect * bvp)
 {
   int i;
 
