@@ -249,7 +249,7 @@ struct
      "SDCC cannot pass structure '%s' as function argument", 0 },
   { E_PREV_DEF_CONFLICT, ERROR_LEVEL_ERROR,
      "conflict with previous definition of '%s' for attribute '%s'", 0 },
-  { E_CODE_NO_INIT, ERROR_LEVEL_ERROR,
+  { E_CODE_NO_INIT, ERROR_LEVEL_WARNING,
      "variable '%s' declared in code space must have initialiser", 0 },
   { E_OPS_INTEGRAL, ERROR_LEVEL_ERROR,
      "operands not integral for assignment operation", 0 },
@@ -431,9 +431,9 @@ struct
   { W_C89_NO_FLEXARRAY, ERROR_LEVEL_PEDANTIC,
      "ISO C90 does not support flexible array members", 0 },
   { E_FLEXARRAY_NOTATEND, ERROR_LEVEL_ERROR,
-     "flexible array member not at end of struct", 0 },
+     "flexible array member '%s' not at end of struct", 0 },
   { E_FLEXARRAY_INEMPTYSTRCT, ERROR_LEVEL_ERROR,
-     "flexible array in otherwise empty struct", 0 },
+     "flexible array '%s' in otherwise empty struct", 0 },
   { W_EMPTY_SOURCE_FILE, ERROR_LEVEL_PEDANTIC,
      "ISO C forbids an empty source file", 0 },
   { W_BAD_PRAGMA_ARGUMENTS, ERROR_LEVEL_WARNING,
@@ -479,7 +479,7 @@ struct
   { W_STRING_CANNOT_BE_TERMINATED, ERROR_LEVEL_PEDANTIC,
     "string '%s'cannot be terminated within array", 0 },
   { W_LONGLONG_LITERAL, ERROR_LEVEL_WARNING,
-    "support for long long literals is incomplete", 0 },
+    "support for large long long literals is incomplete", 0 },
   { S_SYNTAX_ERROR, ERROR_LEVEL_SYNTAX_ERROR,
     "token -> '%s' ; column %d", 0 },
   { E_MIXING_CONFIG, ERROR_LEVEL_ERROR,
@@ -493,6 +493,18 @@ struct
      "Contact Author with source code", 0 },
   { W_UNRECOGNIZED_ASM, ERROR_LEVEL_INFO,
      "%s() failed to parse line node, assuming %d bytes\n'%s'\n", 0 },
+  { W_FLEXARRAY_INSTRUCT, ERROR_LEVEL_WARNING,
+     "type of variable '%s' is struct with flexible array field", 0},
+  { W_ANONYMOUS_MEMBER, ERROR_LEVEL_WARNING,
+     "anonymous member in struct/union", 0},
+  { W_INLINE_NAKED, ERROR_LEVEL_WARNING,
+     "inline function '%s' is __naked", 0},
+  { E_Z88DK_FASTCALL_PARAMETERS, ERROR_LEVEL_ERROR,
+    "invalid number of parameters for __z88dk_fastcall", 0 },
+  { E_Z88DK_FASTCALL_PARAMETER, ERROR_LEVEL_ERROR,
+    "ivalid parameter type in __z88dk_fastcall", 0 },
+  { W_REPEAT_QUALIFIER, ERROR_LEVEL_WARNING,
+    "duplicate specifier '%s'", 0 },
 };
 
 /* -------------------------------------------------------------------------------
