@@ -128,7 +128,7 @@ enum {
   E_CODE_NO_INIT                =  99, /* vars in code space must have initializer */
   E_OPS_INTEGRAL                = 100, /* operans must be integral for certain assignments */
   E_TOO_MANY_PARMS              = 101, /* too many parameters */
-  E_TOO_FEW_PARMS               = 102, /* to few parameters   */
+  E_TOO_FEW_PARMS               = 102, /* too few parameters  */
   E_FUNC_NO_CODE                = 103, /* fatalError          */
   E_TYPE_MISMATCH_PARM          = 104, /* type mismatch for parameter */
   E_INVALID_FLOAT_CONST         = 105, /* invalid floating point literal string */
@@ -155,7 +155,7 @@ enum {
   W_CODE_UNREACH                = 126, /* unreachable code    */
   W_NONPTR2_GENPTR              = 127, /* non pointer cast to generic pointer */
   W_POSSBUG                     = 128, /* possible code generation error */
-  E_INCOMPAT_PTYPES             = 129, /* incampatible pointer assignment */
+  E_INCOMPAT_PTYPES             = 129, /* incompatible pointer assignment */
   W_UNKNOWN_MODEL               = 130, /* Unknown memory model */
   E_UNKNOWN_TARGET              = 131, /* target not defined  */
   W_INDIR_BANKED                = 132, /* Indirect call to a banked fun */
@@ -243,6 +243,14 @@ enum {
   E_MIXING_CONFIG               = 214, /* mixing __CONFIG and CONFIG directives */
   W_STATIC_ASSERTION            = 215, /* static assertion failed */
   E_ALIGNAS                     = 216, /* invalid alignment specified */
+  W_INTERNAL_ERROR              = 217, /* warning for non-fatal internal errors - things that should not have happened, but can be handled */
+  W_UNRECOGNIZED_ASM            = 218, /* unrecognized asm instruction in peephole optimizer */
+  W_FLEXARRAY_INSTRUCT          = 219, /* using flexible arrays in a struct */
+  W_ANONYMOUS_MEMBER            = 220, /* anonymous member in struct/union */
+  W_INLINE_NAKED                = 221, /* inline function is naked */
+  E_Z88DK_FASTCALL_PARAMETERS   = 222, /* invalid number of parameters in __z88dk_fastcall */
+  E_Z88DK_FASTCALL_PARAMETER    = 223, /* invalid parameter type in __z88dk_fastcall */
+  W_REPEAT_QUALIFIER            = 224, /* the same qualifier appears more than once */
 
   /* don't touch this! */
   NUMBER_OF_ERROR_MESSAGES             /* Number of error messages */
