@@ -237,7 +237,7 @@ struct optimize
     int codeSpeed;
     int codeSize;
     int lospre;
-    int lospre_unsafe_read;
+    int allow_unsafe_read;
   };
 
 /** Build model.
@@ -393,7 +393,7 @@ void setParseWithComma (set **, const char *);
 /** An assert() macro that will go out through sdcc's error
     system.
 */
-#define wassertl(a,s)   ((a) ? 0 : \
+#define wassertl(a,s)   (void)((a) ? 0 : \
         (werror (E_INTERNAL_ERROR, __FILE__, __LINE__, s), 0))
 
 #define wassert(a)    wassertl(a,"code generator internal error")
