@@ -136,7 +136,7 @@ setLiveFrom (symbol * sym, int from)
 /* setToRange - set the range to for an operand                    */
 /*-----------------------------------------------------------------*/
 static void
-setLiveTo (symbol * sym, int to)
+setLiveTo (symbol *sym, int to)
 {
   if (!sym->liveTo || sym->liveTo < to)
     sym->liveTo = to;
@@ -146,7 +146,7 @@ setLiveTo (symbol * sym, int to)
 /* markLiveRanges - for each operand mark the liveFrom & liveTo    */
 /*-----------------------------------------------------------------*/
 static void
-markLiveRanges (eBBlock ** ebbs, int count)
+markLiveRanges (eBBlock **ebbs, int count)
 {
   int i, key;
   symbol *sym;
@@ -456,7 +456,7 @@ findPrevUse (eBBlock *ebp, iCode *ic, operand *op,
   /* There must be a definition in each branch of predecessors */
   if (!findPrevUseSym (ebp, ic->prev, OP_SYMBOL(op)))
     {
-      /* computeLiveRanges() is called twice */
+      /* computeLiveRanges() is called at least twice */
       if (emitWarnings)
         {
           if (IS_ITEMP (op))
@@ -501,7 +501,7 @@ incUsed (iCode *ic, operand *op)
 /* rliveClear - clears the rlive bitVectors                        */
 /*-----------------------------------------------------------------*/
 static void
-rliveClear (eBBlock ** ebbs, int count)
+rliveClear (eBBlock **ebbs, int count)
 {
   int i;
 
@@ -513,9 +513,9 @@ rliveClear (eBBlock ** ebbs, int count)
       /* for all instructions in this block do */
       for (ic = ebbs[i]->sch; ic; ic = ic->next)
         {
-	  freeBitVect (ic->rlive);
-	  ic->rlive = NULL;
-	}
+	      freeBitVect (ic->rlive);
+	      ic->rlive = NULL;
+	    }
     }
 }
 
@@ -846,7 +846,7 @@ adjustIChain (eBBlock ** ebbs, int count)
 /* computeLiveRanges - computes the live ranges for variables      */
 /*-----------------------------------------------------------------*/
 void
-computeLiveRanges (eBBlock ** ebbs, int count, bool emitWarnings)
+computeLiveRanges (eBBlock **ebbs, int count, bool emitWarnings)
 {
   /* first look through all blocks and adjust the
      sch and ech pointers */
@@ -878,7 +878,7 @@ computeLiveRanges (eBBlock ** ebbs, int count, bool emitWarnings)
 /* recomputeLiveRanges - recomputes the live ranges for variables  */
 /*-----------------------------------------------------------------*/
 void
-recomputeLiveRanges (eBBlock ** ebbs, int count)
+recomputeLiveRanges (eBBlock **ebbs, int count, bool emitWarnings)
 {
   symbol * sym;
   int key;
@@ -899,7 +899,7 @@ recomputeLiveRanges (eBBlock ** ebbs, int count)
     }
 
   /* do the LR computation again */
-  computeLiveRanges (ebbs, count, FALSE);
+  computeLiveRanges (ebbs, count, emitWarnings);
 }
 
 /*-----------------------------------------------------------------*/
@@ -939,3 +939,164 @@ dumpIcRlive (eBBlock ** ebbs, int count)
     }
 }
 #endif
+
+static void visit (set **visited, iCode *ic, const int key)
+{
+  symbol *lbl;
+
+  while (ic && !isinSet (*visited, ic) && bitVectBitValue (ic->rlive, key))
+    {
+      addSet (visited, ic);
+
+      switch (ic->op)
+        {
+        case GOTO:
+          ic = hTabItemWithKey (labelDef, (IC_LABEL (ic))->key);
+          break;
+        case RETURN:
+          ic = hTabItemWithKey (labelDef, returnLabel->key);
+          break;
+        case JUMPTABLE:
+          for (lbl = setFirstItem (IC_JTLABELS (ic)); lbl; lbl = setNextItem (IC_JTLABELS (ic)))
+            visit (visited, hTabItemWithKey (labelDef, lbl->key), key);
+          break;
+        case IFX:
+          visit (visited, hTabItemWithKey (labelDef, (IC_TRUE(ic) ? IC_TRUE (ic) : IC_FALSE (ic))->key), key);
+          ic = ic->next;
+          break;
+        default:
+          ic = ic->next;
+          if (!POINTER_SET (ic) && IC_RESULT (ic) && IS_SYMOP (IC_RESULT (ic)) && OP_SYMBOL_CONST (IC_RESULT (ic))->key == key)
+            {
+              addSet (visited, ic);
+              return;
+            }
+        }
+    }
+}
+
+/*-----------------------------------------------------------------*/
+/* Split temporaries that have non-connected live ranges           */
+/* Such temporaries can result from GCSE and losrpe,               */
+/* And can confuse register allocation and rematerialization.      */
+/*-----------------------------------------------------------------*/
+void
+separateLiveRanges (iCode *sic, ebbIndex *ebbi)
+{
+  iCode *ic;
+  set *candidates = 0;
+  symbol *sym;
+
+  // printf("separateLiveRanges()\n");
+
+  for (ic = sic; ic; ic = ic->next)
+    {
+      if (ic->op == IFX || ic->op == GOTO || ic->op == JUMPTABLE || !IC_RESULT (ic) || !IS_ITEMP (IC_RESULT (ic)) || bitVectnBitsOn (OP_DEFS (IC_RESULT (ic))) <= 1 || isinSet (candidates, OP_SYMBOL (IC_RESULT (ic))))
+        continue;
+
+      addSet (&candidates, OP_SYMBOL (IC_RESULT (ic)));
+    }
+
+  if (!candidates)
+    return;
+
+  for(sym = setFirstItem (candidates); sym; sym = setNextItem (candidates))
+    {
+      // printf("Looking at %s, %d definitions\n", sym->name, bitVectnBitsOn (sym->defs));
+
+      int i;
+      set *defs = 0;
+
+      for (i = 0; i < sym->defs->size; i++)
+        if (bitVectBitValue (sym->defs, i))
+          {
+            iCode *dic;
+            if(dic = hTabItemWithKey (iCodehTab, i))
+              addSet (&defs, hTabItemWithKey (iCodehTab, i));
+            else
+              {
+                werror (W_INTERNAL_ERROR, __FILE__, __LINE__, "Definition not found");
+                return;
+              }
+          }
+
+      do
+        {
+          set *visited = 0;
+          set *newdefs = 0;
+          int oldsize;
+
+          wassert (defs);
+          wassert (setFirstItem (defs));
+
+          // printf("Looking at def at %d now\n", ((iCode *)(setFirstItem (defs)))->key);
+
+          if (!bitVectBitValue (((iCode *)(setFirstItem (defs)))->rlive, sym->key))
+            {
+              werror (W_INTERNAL_ERROR, __FILE__, __LINE__, "Variable is not alive at one of its definitions");
+              break;
+            }
+ 
+          visit (&visited, setFirstItem (defs), sym->key);
+          addSet (&newdefs, setFirstItem (defs));
+
+          do
+            {
+              oldsize = elementsInSet(visited);
+              ic = setFirstItem (defs);
+              for(ic = setNextItem (defs); ic; ic = setNextItem (defs))
+                {
+                  // printf("Looking at other def at %d now\n", ic->key);
+                  set *visited2 = 0;
+                  set *intersection = 0;
+                  visit (&visited2, ic, sym->key);
+                  intersection = intersectSets (visited, visited2, THROW_NONE);
+                  intersection = subtractFromSet (intersection, defs, THROW_DEST);
+                  if (intersection)
+                    {
+                      visited = unionSets (visited, visited2, THROW_DEST);
+                      addSet (&newdefs, ic);
+                    }
+                  deleteSet (&intersection);
+                  deleteSet (&visited2);
+                }
+             }
+          while (oldsize < elementsInSet(visited));
+
+          defs = subtractFromSet (defs, newdefs, THROW_DEST);
+
+          if (newdefs && defs)
+            {
+              operand *tmpop = newiTempOperand (operandType (IC_RESULT ((iCode *)(setFirstItem (newdefs)))), TRUE);
+
+              // printf("Splitting %s from %s, using def at %d, op %d\n", OP_SYMBOL_CONST(tmpop)->name, sym->name, ((iCode *)(setFirstItem (newdefs)))->key, ((iCode *)(setFirstItem (newdefs)))->op);
+
+              for (ic = setFirstItem (visited); ic; ic = setNextItem (visited))
+                {
+                  if (IC_LEFT (ic) && IS_ITEMP (IC_LEFT (ic)) && OP_SYMBOL (IC_LEFT (ic)) == sym)
+                    IC_LEFT (ic) = operandFromOperand (tmpop);
+                  if (IC_RIGHT (ic) && IS_ITEMP (IC_RIGHT (ic)) && OP_SYMBOL (IC_RIGHT (ic)) == sym)
+                      IC_RIGHT (ic) = operandFromOperand (tmpop);
+                  if (IC_RESULT (ic) && IS_ITEMP (IC_RESULT (ic)) && OP_SYMBOL (IC_RESULT (ic)) == sym && !POINTER_SET(ic) && ic->next && !isinSet (visited, ic->next))
+                    continue;
+                  if (IC_RESULT (ic) && IS_ITEMP (IC_RESULT (ic)) && OP_SYMBOL (IC_RESULT (ic)) == sym)
+                    {
+                      bool pset = POINTER_SET(ic);
+                      IC_RESULT (ic) = operandFromOperand (tmpop);
+                      if (pset)
+                        IC_RESULT(ic)->isaddr = TRUE;
+                    }
+                  bitVectUnSetBit (sym->uses, ic->key);
+                }
+            }
+          deleteSet (&newdefs);
+          deleteSet (&visited);
+        }
+      while (elementsInSet(defs) > 1);
+
+      deleteSet (&defs);
+    }
+
+  deleteSet (&candidates);
+}
+
