@@ -105,7 +105,6 @@ template <class I_t>
 void thorup_E(std::multimap<unsigned int, unsigned int> &M, const I_t &I)
 {
   typedef typename boost::graph_traits<I_t>::adjacency_iterator adjacency_iter_t;
-  typedef typename boost::graph_traits<I_t>::vertex_iterator vertex_iter_t;
   typedef typename boost::property_map<I_t, boost::vertex_index_t>::type index_map;
   index_map index = boost::get(boost::vertex_index, I);
 
@@ -143,7 +142,7 @@ void thorup_E(std::multimap<unsigned int, unsigned int> &M, const I_t &I)
       s.push(std::pair<int, unsigned int>(i2, j));
     }
     
-    // Not in Thorup's paper, but without this the algorithm gives incorrect results.
+    // Thorup forgot this in his paper. Without it, some maximal chains are omitted.
     while(s.size() > 1)
     {
         M.insert(std::pair<unsigned int, unsigned int>(s.top().second, s.top().first));
@@ -158,7 +157,7 @@ void thorup_E(std::multimap<unsigned int, unsigned int> &M, const I_t &I)
 template <class l_t, class G_t>
 void thorup_elimination_ordering(l_t &l, const G_t &G)
 {
-  // Should we do this? Or just use G as J? The Thorup paper seems unclear, it speaks of statements that contain jumps to other statements, but does it count as a jump, when they're just subsequent?
+  // Remove edges to immediately following instruction. By "each statement can have at most obne jump" in the last paragraph of Appendix A it is clear that Thorup does not consider the implicit next-instruction-edges as jumps.
   boost::adjacency_list<boost::vecS, boost::vecS, boost::directedS> J;
   boost::copy_graph(G, J, boost::vertex_copy(forget_properties()).edge_copy(forget_properties()));
   for (unsigned int i = 0; i < boost::num_vertices(J) - 1; i++)
@@ -255,7 +254,7 @@ void add_vertices_to_tree_decomposition(T_t &T, const v_t v, const v_t v_end, G_
   T[s].bag.insert(*v);
 }
 
-// Create a tree decomposition from en elimination ordering.
+// Create a tree decomposition from an elimination ordering.
 template <class T_t, class G_t>
 void tree_decomposition_from_elimination_ordering(T_t &T, const std::list<unsigned int>& l, const G_t &G)
 {
@@ -404,9 +403,12 @@ void nicify_diffs_more(T_t &T, typename boost::graph_traits<T_t>::vertex_descrip
           typename boost::graph_traits<T_t>::vertex_descriptor d = boost::add_vertex(T);
           T[d].bag = T[t].bag;
           T[d].bag.erase(T[d].bag.begin());
+          T[d].weight = 0;
           boost::add_edge(t, d, T);
           nicify_diffs_more(T, t);
         }
+      else
+        T[t].weight = 0;
       return;
     case 1:
       break;
@@ -415,6 +417,11 @@ void nicify_diffs_more(T_t &T, typename boost::graph_traits<T_t>::vertex_descrip
       c1 = *c;
       nicify_diffs_more(T, c0);
       nicify_diffs_more(T, c1);
+      {
+        const unsigned l = T[c0].weight;
+        const unsigned r = T[c1].weight;
+        T[t].weight = (l == r) ? l + 1 : std::max(l , r);
+      }
       return;
     default:
       std::cerr << "nicify_diffs_more error.\n";
@@ -430,6 +437,7 @@ void nicify_diffs_more(T_t &T, typename boost::graph_traits<T_t>::vertex_descrip
   if (t_size <= c0_size + 1 && t_size + 1 >= c0_size)
     {
       nicify_diffs_more(T, c0);
+      T[t].weight = T[c0].weight;
       return;
     }
 
