@@ -70,7 +70,6 @@ static void
 emitPseudoStack(struct dbuf_s *oBuf, struct dbuf_s *oBufExt)
 {
     int shared, low, high, size, i;
-    PIC_device *pic;
 
     /* also emit STK symbols
      * XXX: This is ugly and fails as soon as devices start to get
@@ -80,8 +79,6 @@ emitPseudoStack(struct dbuf_s *oBuf, struct dbuf_s *oBufExt)
     shared = pic14_getSharedStack(&low, &high, &size);
     if (!pic14_options.isLibrarySource)
     {
-        pic = pic14_getPIC();
-
         dbuf_printf (oBuf, "\n");
         dbuf_printf (oBuf, "\tglobal PSAVE\n");
         dbuf_printf (oBuf, "\tglobal SSAVE\n");
@@ -145,7 +142,7 @@ pic14_constructAbsMap (struct dbuf_s *oBuf, struct dbuf_s *gloBuf)
   symbol *sym;
   set *aliases;
   int addr, min=-1, max=-1;
-  int size;
+  unsigned int size;
 
   for (i=0; maps[i] != NULL; i++)
   {
@@ -919,7 +916,7 @@ static void
 emitInitVal(struct dbuf_s *oBuf, symbol *topsym, sym_link *my_type, initList *list)
 {
     symbol *sym;
-    int size, i;
+    int size;
     long lit;
     unsigned char *str;
 
@@ -966,7 +963,9 @@ emitInitVal(struct dbuf_s *oBuf, symbol *topsym, sym_link *my_type, initList *li
     }
 
     if (IS_ARRAY(my_type)) {
-        DEBUGprintf ("(array, %d items, %d byte) below\n", DCL_ELEM(my_type), size);
+        size_t i;
+
+        DEBUGprintf ("(array, %d items, %ud byte) below\n", (unsigned int) DCL_ELEM(my_type), size);
         assert (!list || list->type == INIT_DEEP);
         if (list) list = list->init.deep;
         for (i = 0; i < DCL_ELEM(my_type); i++) {
