@@ -379,7 +379,7 @@ pic16_initPointer (initList * ilist, sym_link *toType)
   ast *expr;
 
   if (!ilist) {
-      return valCastLiteral(toType, 0.0);
+      return valCastLiteral(toType, 0.0, 0);
   }
 
   expr = decorateType(resolveSymbols( list2expr (ilist) ), FALSE);
@@ -617,13 +617,13 @@ pic16_printIvalType (symbol *sym, sym_link * type, initList * ilist, char ptype,
     werror (W_EXCESS_INITIALIZERS, "scalar", sym->name, sym->lineDef);
   }
 
-  if (!(val = list2val (ilist))) {
+  if (!(val = list2val (ilist, TRUE))) {
     // assuming a warning has been thrown
     val = constCharVal (0);
   }
 
   if (val->type != type) {
-    val = valCastLiteral(type, floatFromVal(val));
+    val = valCastLiteral(type, floatFromVal (val), ullFromVal (val));
   }
 
   for (i = 0; i < (int)getSize (type); i++) {
@@ -649,7 +649,7 @@ pic16_printIvalChar (symbol *sym, sym_link * type, initList * ilist, const char
 #endif
 
   if(!s) {
-    val = list2val (ilist);
+    val = list2val (ilist, TRUE);
 
     /* if the value is a character string  */
     if(IS_ARRAY (val->type) && IS_CHAR (val->etype)) {
@@ -731,7 +731,7 @@ pic16_printIvalArray (symbol * sym, sym_link * type, initList * ilist,
   /* by a string                      */
   if (IS_CHAR (type->next) &&
       ilist && ilist->type == INIT_NODE) {
-    if (!IS_LITERAL(list2val(ilist)->etype)) {
+    if (!IS_LITERAL(list2val(ilist, TRUE)->etype)) {
       werror (W_INIT_WRONG);
       return;
     }
@@ -815,7 +815,7 @@ pic16_printIvalBitFields (symbol **sym, initList **ilist, char ptype, void *p)
       else if (!SPEC_BUNNAMED (lsym->etype))
         {
           /* not an unnamed bit-field structure member */
-          value *val = list2val (lilist);
+          value *val = list2val (lilist, TRUE);
 
           if (size)
             {
@@ -1027,9 +1027,9 @@ pic16_printIvalFuncPtr (sym_link * type, initList * ilist, char ptype, void *p)
 #endif
 
   if (ilist)
-    val = list2val (ilist);
+    val = list2val (ilist, TRUE);
   else
-    val = valCastLiteral(type, 0.0);
+    val = valCastLiteral(type, 0.0, 0);
 
   if (!val) {
     // an error has been thrown already
@@ -1296,13 +1296,13 @@ CODESPACE: %d\tCONST: %d\tPTRCONST: %d\tSPEC_CONST: %d\n", __FUNCTION__, map->sn
 
       if (SPEC_ABSA (sym->etype) && PIC16_IS_CONFIG_ADDRESS (SPEC_ADDR (sym->etype)))
         {
-          pic16_assignConfigWordValue (SPEC_ADDR (sym->etype), (int) ulFromVal (list2val (sym->ival)));
+          pic16_assignConfigWordValue (SPEC_ADDR (sym->etype), (int) ulFromVal (list2val (sym->ival, TRUE)));
           continue;
         }
 
       if (SPEC_ABSA (sym->etype) && PIC16_IS_IDLOC_ADDRESS (SPEC_ADDR (sym->etype)))
         {
-          pic16_assignIdByteValue (SPEC_ADDR (sym->etype), (char) ulFromVal (list2val (sym->ival)));
+          pic16_assignIdByteValue (SPEC_ADDR (sym->etype), (char) ulFromVal (list2val (sym->ival, TRUE)));
           continue;
         }
 
