@@ -98,6 +98,176 @@ add_line_note (cpp_buffer *buffer, const uchar *pos, unsigned int type)
   buffer->notes_used++;
 }
 
+
+/* Fast path to find line special characters using optimized character
+   scanning algorithms.  Anything complicated falls back to the slow
+   path below.  Since this loop is very hot it's worth doing these kinds
+   of optimizations.
+
+   One of the paths through the ifdefs should provide
+
+     const uchar *search_line_fast (const uchar *s, const uchar *end);
+
+   Between S and END, search for \n, \r, \\, ?.  Return a pointer to
+   the found character.
+
+   Note that the last character of the buffer is *always* a newline,
+   as forced by _cpp_convert_input.  This fact can be used to avoid
+   explicitly looking for the end of the buffer.  */
+
+/* Configure gives us an ifdef test.  */
+#ifndef WORDS_BIGENDIAN
+#define WORDS_BIGENDIAN 0
+#endif
+
+/* We'd like the largest integer that fits into a register.  There's nothing
+   in <stdint.h> that gives us that.  For most hosts this is unsigned long,
+   but MS decided on an LLP64 model.  Thankfully when building with GCC we
+   can get the "real" word size.  */
+#ifdef __GNUC__
+typedef unsigned int word_type __attribute__((__mode__(__word__)));
+#else
+typedef unsigned long word_type;
+#endif
+
+/* The code below is only expecting sizes 4 or 8.
+   Die at compile-time if this expectation is violated.  */
+typedef char check_word_type_size
+  [(sizeof(word_type) == 8 || sizeof(word_type) == 4) * 2 - 1];
+
+/* Return X with the first N bytes forced to values that won't match one
+   of the interesting characters.  Note that NUL is not interesting.  */
+
+static inline word_type
+acc_char_mask_misalign (word_type val, unsigned int n)
+{
+  word_type mask = -1;
+  if (WORDS_BIGENDIAN)
+    mask >>= n * 8;
+  else
+    mask <<= n * 8;
+  return val & mask;
+}
+
+/* Return X replicated to all byte positions within WORD_TYPE.  */
+
+static inline word_type
+acc_char_replicate (uchar x)
+{
+  word_type ret;
+
+  ret = (x << 24) | (x << 16) | (x << 8) | x;
+  if (sizeof(word_type) == 8)
+    ret = (ret << 16 << 16) | ret;
+  return ret;
+}
+
+/* Return non-zero if some byte of VAL is (probably) C.  */
+
+static inline word_type
+acc_char_cmp (word_type val, word_type c)
+{
+#if defined(__GNUC__) && defined(__alpha__)
+  /* We can get exact results using a compare-bytes instruction.
+     Get (val == c) via (0 >= (val ^ c)).  */
+  return __builtin_alpha_cmpbge (0, val ^ c);
+#else
+  word_type magic = 0x7efefefeU;
+  if (sizeof(word_type) == 8)
+    magic = (magic << 16 << 16) | 0xfefefefeU;
+  magic |= 1;
+
+  val ^= c;
+  return ((val + magic) ^ ~val) & ~magic;
+#endif
+}
+
+/* Given the result of acc_char_cmp is non-zero, return the index of
+   the found character.  If this was a false positive, return -1.  */
+
+static inline int
+acc_char_index (word_type cmp ATTRIBUTE_UNUSED,
+                word_type val ATTRIBUTE_UNUSED)
+{
+#if defined(__GNUC__) && defined(__alpha__) && !WORDS_BIGENDIAN
+  /* The cmpbge instruction sets *bits* of the result corresponding to
+     matches in the bytes with no false positives.  */
+  return __builtin_ctzl (cmp);
+#else
+  unsigned int i;
+
+  /* ??? It would be nice to force unrolling here,
+     and have all of these constants folded.  */
+  for (i = 0; i < sizeof(word_type); ++i)
+    {
+      uchar c;
+      if (WORDS_BIGENDIAN)
+        c = (val >> (sizeof(word_type) - i - 1) * 8) & 0xff;
+      else
+        c = (val >> i * 8) & 0xff;
+
+      if (c == '\n' || c == '\r' || c == '\\' || c == '?')
+        return i;
+    }
+
+  return -1;
+#endif
+}
+
+/* A version of the fast scanner using bit fiddling techniques.
+
+   For 32-bit words, one would normally perform 16 comparisons and
+   16 branches.  With this algorithm one performs 24 arithmetic
+   operations and one branch.  Whether this is faster with a 32-bit
+   word size is going to be somewhat system dependent.
+
+   For 64-bit words, we eliminate twice the number of comparisons
+   and branches without increasing the number of arithmetic operations.
+   It's almost certainly going to be a win with 64-bit word size.  */
+
+static const uchar * search_line_acc_char (const uchar *, const uchar *)
+  ATTRIBUTE_UNUSED;
+
+static const uchar *
+search_line_acc_char (const uchar *s, const uchar *end ATTRIBUTE_UNUSED)
+{
+  const word_type repl_nl = acc_char_replicate ('\n');
+  const word_type repl_cr = acc_char_replicate ('\r');
+  const word_type repl_bs = acc_char_replicate ('\\');
+  const word_type repl_qm = acc_char_replicate ('?');
+
+  unsigned int misalign;
+  const word_type *p;
+  word_type val, t;
+
+  /* Align the buffer.  Mask out any bytes from before the beginning.  */
+  p = (word_type *)((uintptr_t)s & -sizeof(word_type));
+  val = *p;
+  misalign = (uintptr_t)s & (sizeof(word_type) - 1);
+  if (misalign)
+    val = acc_char_mask_misalign (val, misalign);
+
+  /* Main loop.  */
+  while (1)
+    {
+      t  = acc_char_cmp (val, repl_nl);
+      t |= acc_char_cmp (val, repl_cr);
+      t |= acc_char_cmp (val, repl_bs);
+      t |= acc_char_cmp (val, repl_qm);
+
+      if (__builtin_expect (t != 0, 0))
+        {
+          int i = acc_char_index (t, val);
+          if (i >= 0)
+            return (const uchar *)p + i;
+        }
+
+      val = *++p;
+    }
+}
+
+#define search_line_fast  search_line_acc_char
+
 /* Returns with a logical line that contains no escaped newlines or
    trigraphs.  This is a time-critical inner loop.  */
 void
@@ -111,82 +281,91 @@ _cpp_clean_line (cpp_reader *pfile)
   buffer->cur_note = buffer->notes_used = 0;
   buffer->cur = buffer->line_base = buffer->next_line;
   buffer->need_line = false;
-  s = buffer->next_line - 1;
+  s = buffer->next_line;
 
   if (!buffer->from_stage3)
     {
       const uchar *pbackslash = NULL;
 
-      /* Short circuit for the common case of an un-escaped line with
+      /* Fast path.  This is the common case of an un-escaped line with
          no trigraphs.  The primary win here is by not writing any
          data back to memory until we have to.  */
-      for (;;)
+      while (1)
         {
-          c = *++s;
-          if (__builtin_expect (c == '\n', false)
-              || __builtin_expect (c == '\r', false))
+          /* Perform an optimized search for \n, \r, \\, ?.  */
+          s = search_line_fast (s, buffer->rlimit);
+
+          c = *s;
+          if (c == '\\')
             {
-              d = (uchar *) s;
-
-              if (__builtin_expect (s == buffer->rlimit, false))
-                goto done;
-
-              /* DOS line ending? */
-              if (__builtin_expect (c == '\r', false)
-                  && s[1] == '\n')
-                {
-                  s++;
-                  if (s == buffer->rlimit)
-                    goto done;
-                }
-
-              if (__builtin_expect (pbackslash == NULL, true))
-                goto done;
-
-              /* Check for escaped newline.  */
-              p = d;
-              while (is_nvspace (p[-1]))
-                p--;
-              if (p - 1 != pbackslash)
-                goto done;
-
-              /* Have an escaped newline; process it and proceed to
-                 the slow path.  */
-              add_line_note (buffer, p - 1, p != d ? ' ' : '\\');
-              d = p - 2;
-              buffer->next_line = p - 1;
-              break;
+              /* Record the location of the backslash and continue.  */
+              pbackslash = s++;
             }
-          if (__builtin_expect (c == '\\', false))
-            pbackslash = s;
-          else if (__builtin_expect (c == '?', false)
-                   && __builtin_expect (s[1] == '?', false)
+          else if (__builtin_expect (c == '?', 0))
+            {
+              if (__builtin_expect (s[1] == '?', false)
                    && _cpp_trigraph_map[s[2]])
-            {
-              /* Have a trigraph.  We may or may not have to convert
-                 it.  Add a line note regardless, for -Wtrigraphs.  */
-              add_line_note (buffer, s, s[2]);
-              if (CPP_OPTION (pfile, trigraphs))
                 {
-                  /* We do, and that means we have to switch to the
-                     slow path.  */
-                  d = (uchar *) s;
-                  *d = _cpp_trigraph_map[s[2]];
-                  s += 2;
-                  break;
+                  /* Have a trigraph.  We may or may not have to convert
+                     it.  Add a line note regardless, for -Wtrigraphs.  */
+                  add_line_note (buffer, s, s[2]);
+                  if (CPP_OPTION (pfile, trigraphs))
+                    {
+                      /* We do, and that means we have to switch to the
+                         slow path.  */
+                      d = (uchar *) s;
+                      *d = _cpp_trigraph_map[s[2]];
+                      s += 2;
+                      goto slow_path;
+                    }
                 }
+              /* Not a trigraph.  Continue on fast-path.  */
+              s++;
             }
+          else
+            break;
         }
 
+      /* This must be \r or \n.  We're either done, or we'll be forced
+         to write back to the buffer and continue on the slow path.  */
+      d = (uchar *) s;
 
-      for (;;)
+      if (__builtin_expect (s == buffer->rlimit, false))
+        goto done;
+
+      /* DOS line ending? */
+      if (__builtin_expect (c == '\r', false) && s[1] == '\n')
+        {
+          s++;
+          if (s == buffer->rlimit)
+            goto done;
+        }
+
+      if (__builtin_expect (pbackslash == NULL, true))
+        goto done;
+
+      /* Check for escaped newline.  */
+      p = d;
+      while (is_nvspace (p[-1]))
+        p--;
+      if (p - 1 != pbackslash)
+        goto done;
+
+      /* Have an escaped newline; process it and proceed to
+         the slow path.  */
+      add_line_note (buffer, p - 1, p != d ? ' ' : '\\');
+      d = p - 2;
+      buffer->next_line = p - 1;
+
+    slow_path:
+      while (1)
         {
           c = *++s;
           *++d = c;
 
           if (c == '\n' || c == '\r')
             {
-                  /* Handle DOS line endings.  */
+              /* Handle DOS line endings.  */
               if (c == '\r' && s != buffer->rlimit && s[1] == '\n')
                 s++;
               if (s == buffer->rlimit)
@@ -217,9 +396,8 @@ _cpp_clean_line (cpp_reader *pfile)
     }
   else
     {
-      do
+      while (*s != '\n' && *s != '\r')
         s++;
-      while (*s != '\n' && *s != '\r');
       d = (uchar *) s;
 
       /* Handle DOS line endings.  */
@@ -313,8 +491,8 @@ _cpp_process_line_notes (cpp_reader *pfile, int in_comment)
                                      (int) _cpp_trigraph_map[note->type]);
               else
                 {
-		  cpp_warning_with_line 
-		    (pfile, CPP_W_TRIGRAPHS,
+                  cpp_warning_with_line
+                    (pfile, CPP_W_TRIGRAPHS,
                      pfile->line_table->highest_line, col,
                      "trigraph ??%c ignored, use -trigraphs to enable",
                      note->type);
@@ -329,15 +507,15 @@ _cpp_process_line_notes (cpp_reader *pfile, int in_comment)
   return ret;
 }
 
-/* SDCC _asm specific */
-/* Skip an _asm ... _endasm block.  We find the end of the comment by
-   seeing _endasm.  Returns non-zero if _asm terminated by EOF, zero
+/* SDCC __asm specific */
+/* Skip an __asm ... __endasm block.  We find the end of the comment by
+   seeing __endasm.  Returns non-zero if _asm terminated by EOF, zero
    otherwise.  */
 static int
 _sdcpp_skip_asm_block (cpp_reader *pfile)
 {
-#define _ENDASM_STR "endasm"
-#define _ENDASM_LEN ((sizeof _ENDASM_STR) - 1)
+#define ENDASM_STR "endasm"
+#define ENDASM_LEN ((sizeof ENDASM_STR) - 1)
 
   cpp_buffer *buffer = pfile->buffer;
   uchar c = EOF;
@@ -348,15 +526,14 @@ _sdcpp_skip_asm_block (cpp_reader *pfile)
       prev_space = is_space(c);
       c = *buffer->cur++;
 
-      if (prev_space && c == '_')
+      if (prev_space && c == '_' && *buffer->cur == '_')
         {
-          /* check if it is _endasm or __endasm */
-          if (*buffer->cur == '_')
-            ++buffer->cur;
-          if (buffer->cur + _ENDASM_LEN <= buffer->rlimit &&
-            strncmp((const char *)buffer->cur, _ENDASM_STR, _ENDASM_LEN) == 0)
+          /* check if it is __endasm */
+          ++buffer->cur;
+          if (buffer->cur + ENDASM_LEN <= buffer->rlimit &&
+            strncmp((const char *)buffer->cur, ENDASM_STR, ENDASM_LEN) == 0)
             {
-              buffer->cur += _ENDASM_LEN;
+              buffer->cur += ENDASM_LEN;
               break;
             }
         }
@@ -503,7 +680,7 @@ name_p (cpp_reader *pfile, const cpp_string *string)
 /* After parsing an identifier or other sequence, produce a warning about
    sequences not in NFC/NFKC.  */
 static void
-warn_about_normalization (cpp_reader *pfile, 
+warn_about_normalization (cpp_reader *pfile,
                           const cpp_token *token,
                           const struct normalize_state *s)
 {
@@ -1200,8 +1377,8 @@ lex_raw_string (cpp_reader *pfile, cpp_token *token, const uchar *base,
                                        raw_prefix_len) == 0
                            && cur[raw_prefix_len+1] == '"')
                     {
-		      BUF_APPEND (")", 1);
-		      base++;
+                      BUF_APPEND (")", 1);
+                      base++;
                       cur += raw_prefix_len + 2;
                       goto break_outer_loop;
                     }
@@ -1449,14 +1626,14 @@ cpp_get_comments (cpp_reader *pfile)
 }
 
 /* Append a comment to the end of the comment table. */
-static void 
-store_comment (cpp_reader *pfile, cpp_token *token) 
+static void
+store_comment (cpp_reader *pfile, cpp_token *token)
 {
   int len;
 
   if (pfile->comments.allocated == 0)
     {
-      pfile->comments.allocated = 256; 
+      pfile->comments.allocated = 256;
       pfile->comments.entries = (cpp_comment *) xmalloc
         (pfile->comments.allocated * sizeof (cpp_comment));
     }
@@ -1472,7 +1649,7 @@ store_comment (cpp_reader *pfile, cpp_token *token)
   len = token->val.str.len;
 
   /* Copy comment. Note, token may not be NULL terminated. */
-  pfile->comments.entries[pfile->comments.count].comment = 
+  pfile->comments.entries[pfile->comments.count].comment =
     (char *) xmalloc (sizeof (char) * (len + 1));
   memcpy (pfile->comments.entries[pfile->comments.count].comment,
           token->val.str.text, len);
@@ -1507,7 +1684,7 @@ save_comment (cpp_reader *pfile, cpp_token *token, const unsigned char *from,
      Note that the only time we encounter a directive here is
      when we are saving comments in a "#define".  */
   clen = ((pfile->state.in_directive || pfile->state.parsing_args)
-	  && type == '/') ? len + 2 : len;
+          && type == '/') ? len + 2 : len;
 
   buffer = _cpp_unaligned_alloc (pfile, clen);
 
@@ -1905,21 +2082,21 @@ _cpp_lex_direct (cpp_reader *pfile)
         warn_about_normalization (pfile, result, &nst);
       }
 
-      /* SDCC _asm specific */
-      /* handle _asm ... _endasm ;  */
-      if (result->val.node.node == pfile->spec_nodes.n__asm || result->val.node.node == pfile->spec_nodes.n__asm1)
+      /* SDCC __asm specific */
+      /* handle __asm ... __endasm ;  */
+      if (result->val.node.node == pfile->spec_nodes.n__asm)
         {
           if (CPP_OPTION (pfile, preproc_asm) == 0)
             {
               comment_start = buffer->cur;
               result->type = CPP_ASM;
               _sdcpp_skip_asm_block (pfile);
-              /* Save the _asm block as a token in its own right.  */
+              /* Save the __asm block as a token in its own right.  */
               _sdcpp_save_asm (pfile, result, comment_start, result->val.node.node == pfile->spec_nodes.n__asm);
             }
           result->flags |= ENTER_ASM;
         }
-      else if (result->val.node.node == pfile->spec_nodes.n__endasm || result->val.node.node == pfile->spec_nodes.n__endasm1)
+      else if (result->val.node.node == pfile->spec_nodes.n__endasm)
         {
           result->flags |= EXIT_ASM;
         }
@@ -1940,7 +2117,7 @@ _cpp_lex_direct (cpp_reader *pfile)
       /* A potential block or line comment.  */
       comment_start = buffer->cur;
       c = *buffer->cur;
-      
+
       if (c == '*')
         {
           if (_cpp_skip_block_comment (pfile))
@@ -1962,7 +2139,7 @@ _cpp_lex_direct (cpp_reader *pfile)
             }
 
           if (skip_line_comment (pfile) && CPP_OPTION (pfile, warn_comments))
-	    cpp_warning (pfile, CPP_W_COMMENTS, "multi-line comment");
+            cpp_warning (pfile, CPP_W_COMMENTS, "multi-line comment");
         }
       else if (c == '=')
         {
@@ -2196,21 +2373,21 @@ utf8_to_ucn (unsigned char *buffer, const unsigned char *name)
   int ucn_len_c;
   unsigned t;
   unsigned long utf32;
-  
+
   /* Compute the length of the UTF-8 sequence.  */
   for (t = *name; t & 0x80; t <<= 1)
     ucn_len++;
-  
+
   utf32 = *name & (0x7F >> ucn_len);
   for (ucn_len_c = 1; ucn_len_c < ucn_len; ucn_len_c++)
     {
       utf32 = (utf32 << 6) | (*++name & 0x3F);
-      
+
       /* Ill-formed UTF-8.  */
       if ((*name & ~0x3F) != 0x80)
         abort ();
     }
-  
+
   *buffer++ = '\\';
   *buffer++ = 'U';
   for (j = 7; j >= 0; j--)
@@ -2267,7 +2444,7 @@ cpp_spell_token (cpp_reader *pfile, const cpp_token *token,
         {
           size_t i;
           const unsigned char * name = NODE_NAME (token->val.node.node);
-          
+
           for (i = 0; i < NODE_LEN (token->val.node.node); i++)
             if (name[i] & ~0x7F)
               {
@@ -2297,7 +2474,7 @@ cpp_spell_token (cpp_reader *pfile, const cpp_token *token,
    freed when the reader is destroyed.  Useful for diagnostics.  */
 unsigned char *
 cpp_token_as_text (cpp_reader *pfile, const cpp_token *token)
-{ 
+{
   unsigned int len = cpp_token_len (token) + 1;
   unsigned char *start = _cpp_unaligned_alloc (pfile, len), *end;
 
@@ -2358,7 +2535,7 @@ cpp_output_token (const cpp_token *token, FILE *fp)
       {
         size_t i;
         const unsigned char * name = NODE_NAME (token->val.node.node);
-        
+
         for (i = 0; i < NODE_LEN (token->val.node.node); i++)
           if (name[i] & ~0x7F)
             {
