@@ -1,19 +1,15 @@
 /** Function pointer tests.
 
-    type: BOOL, char, int, long
+    type: bool, char, int, long
  */
 #include <testfwk.h>
 
-#ifdef SDCC
+#ifdef __SDCC
 #pragma std_sdcc99
 #endif
 
 #include <stdbool.h>
 
-#ifndef BOOL
-#define BOOL	bool
-#endif
-
 #define TYPE_{type}
 
 /* Must use a typedef as there is no way of adding the code modifier
