@@ -8,8 +8,8 @@
 #pragma std_c99
 #endif
 
-#if 0
-TODO: Enable when long long support for constants is there!
+// TODO: Enable when sdcc supports long long in these ports!
+#if !defined(__SDCC_mcs51) && !defined(__SDCC_ds390) && !defined(__SDCC_pic14) && !defined(__SDCC_pic16)
 /* PR middle-end/40057 */
 
 int
@@ -34,9 +34,10 @@ bar (long long x)
 void
 testTortureExecute (void)
 {
-#if 0
+#ifndef PORT_HOST // Fails on NetBSD
+#if !defined(__SDCC_mcs51) && !defined(__SDCC_ds390) && !defined(__SDCC_pic14) && !defined(__SDCC_pic16)
   if (sizeof (long long) != 8)
-    return 0;
+    return;
   if (foo (0x1682a9aaaULL))
     ASSERT (0);
   if (!foo (0x1882a9aaaULL))
@@ -47,5 +48,6 @@ testTortureExecute (void)
     ASSERT (0);
   return;
 #endif
+#endif
 }
 
